@@ -1,5 +1,7 @@
 from __future__ import absolute_import
 
+from StringIO import StringIO
+
 import pandas as pd
 
 def to_records(df):
@@ -18,6 +20,14 @@ def to_records(df):
     yield dict(row)
 
 
+def to_csv(df, **kwargs):
+  """Return CSV as a string"""
+
+  sio = StringIO()
+  df.to_csv(sio, **kwargs)
+  return sio.getvalue()
+
+
 def count(key="count"):
   """Count the number of rows in a Dataframe
 
